package com.ruoyi.ss.complaint.service;

import com.ruoyi.ss.complaint.domain.SmComplaint;
import com.ruoyi.ss.complaint.domain.SmComplaintQuery;
import com.ruoyi.ss.complaint.domain.SmComplaintVo;

import java.util.List;

/**
 * 投诉Service接口
 *
 * @author ruoyi
 * @date 2024-03-02
 */
public interface ISmComplaintService
{
    /**
     * 查询投诉
     *
     * @param id 投诉主键
     * @return 投诉
     */
    public SmComplaint selectSmComplaintById(Long id);

    /**
     * 查询投诉列表
     *
     * @param smComplaint 投诉
     * @return 投诉集合
     */
    public List<SmComplaintVo> selectSmComplaintList(SmComplaintQuery smComplaint);

    /**
     * 新增投诉
     *
     * @param smComplaint 投诉
     * @return 结果
     */
    public int insertSmComplaint(SmComplaint smComplaint);

    /**
     * 修改投诉
     *
     * @param smComplaint 投诉
     * @return 结果
     */
    public int updateSmComplaint(SmComplaint smComplaint);

    /**
     * 批量删除投诉
     *
     * @param ids 需要删除的投诉主键集合
     * @return 结果
     */
    public int deleteSmComplaintByIds(Long[] ids);

    /**
     * 删除投诉信息
     *
     * @param id 投诉主键
     * @return 结果
     */
    public int deleteSmComplaintById(Long id);

    /**
     * 查询数量
     */
    int selectCount(SmComplaintQuery query);
}
